@@ -31,21 +31,16 @@ class DescribeDcdnDomainUsageDataRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_StartTime(self): # String
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self, StartTime):  # String
-		self.add_query_param('StartTime', StartTime)
-	def get_DataProtocol(self): # String
-		return self.get_query_params().get('DataProtocol')
-
-	def set_DataProtocol(self, DataProtocol):  # String
-		self.add_query_param('DataProtocol', DataProtocol)
 	def get_Area(self): # String
 		return self.get_query_params().get('Area')
 
 	def set_Area(self, Area):  # String
 		self.add_query_param('Area', Area)
+	def get_Field(self): # String
+		return self.get_query_params().get('Field')
+
+	def set_Field(self, Field):  # String
+		self.add_query_param('Field', Field)
 	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
@@ -56,18 +51,18 @@ class DescribeDcdnDomainUsageDataRequest(RpcRequest):
 
 	def set_EndTime(self, EndTime):  # String
 		self.add_query_param('EndTime', EndTime)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_Field(self): # String
-		return self.get_query_params().get('Field')
-
-	def set_Field(self, Field):  # String
-		self.add_query_param('Field', Field)
 	def get_Interval(self): # String
 		return self.get_query_params().get('Interval')
 
 	def set_Interval(self, Interval):  # String
 		self.add_query_param('Interval', Interval)
+	def get_StartTime(self): # String
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_DataProtocol(self): # String
+		return self.get_query_params().get('DataProtocol')
+
+	def set_DataProtocol(self, DataProtocol):  # String
+		self.add_query_param('DataProtocol', DataProtocol)
